==> r-base_4.1.2.orig.tar.gz: R-4.1.2/src/library/datasets/data/Theoph.R <==
### $Id: Theoph.R,v 1.1 2003/12/11 07:16:04 ripley Exp $
### Theophylline pharmacokinetic data
### Boeckmann, Sheiner, and Beal (1994), NONMEM Users Guide - Part V.
"Theoph" <-
  structure(list
  (Subject = structure(ordered(c(11, 11, 11, 11,
     11, 11, 11, 11, 11, 11, 11, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
     5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
     7, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 1, 1, 1, 1, 1,
     1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3,
     3, 3, 3, 3, 3, 3, 3, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 10, 10,
     10, 10, 10, 10, 10, 10, 10, 10, 10, 4, 4, 4, 4, 4, 4, 4, 4, 4,
     4, 4, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9), levels=1:12),
     class = c("ordered", "factor"),
     .Label = c("6", "7", "8", "11", "3", "2", "4", "9", "12", "10",
       "1", "5")),
   Wt = c(79.6, 79.6, 79.6, 79.6, 79.6,
     79.6, 79.6, 79.6, 79.6, 79.6, 79.6, 72.4, 72.4, 72.4, 72.4, 72.4,
     72.4, 72.4, 72.4, 72.4, 72.4, 72.4, 70.5, 70.5, 70.5, 70.5, 70.5,
     70.5, 70.5, 70.5, 70.5, 70.5, 70.5, 72.7, 72.7, 72.7, 72.7, 72.7,
     72.7, 72.7, 72.7, 72.7, 72.7, 72.7, 54.6, 54.6, 54.6, 54.6, 54.6,
     54.6, 54.6, 54.6, 54.6, 54.6, 54.6, 80, 80, 80, 80, 80, 80, 80,
     80, 80, 80, 80, 64.6, 64.6, 64.6, 64.6, 64.6, 64.6, 64.6, 64.6,
     64.6, 64.6, 64.6, 70.5, 70.5, 70.5, 70.5, 70.5, 70.5, 70.5, 70.5,
     70.5, 70.5, 70.5, 86.4, 86.4, 86.4, 86.4, 86.4, 86.4, 86.4, 86.4,
     86.4, 86.4, 86.4, 58.2, 58.2, 58.2, 58.2, 58.2, 58.2, 58.2, 58.2,
     58.2, 58.2, 58.2, 65, 65, 65, 65, 65, 65, 65, 65, 65, 65, 65,
     60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5),
   Dose = c(4.02, 4.02, 4.02, 4.02, 4.02, 4.02, 4.02, 4.02, 4.02,
     4.02, 4.02, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4,
     4.4, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53,
     4.53, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4,
     5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86,
     4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4.95, 4.95, 4.95, 4.95, 4.95,
     4.95, 4.95, 4.95, 4.95, 4.95, 4.95, 4.53, 4.53, 4.53, 4.53, 4.53,
     4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 3.1, 3.1, 3.1, 3.1, 3.1,
     3.1, 3.1, 3.1, 3.1, 3.1, 3.1, 5.5, 5.5, 5.5, 5.5, 5.5, 5.5, 5.5,
     5.5, 5.5, 5.5, 5.5, 4.92, 4.92, 4.92, 4.92, 4.92, 4.92, 4.92,
     4.92, 4.92, 4.92, 4.92, 5.3, 5.3, 5.3, 5.3, 5.3, 5.3, 5.3, 5.3,
     5.3, 5.3, 5.3),
   Time = c(0, 0.25, 0.57, 1.12, 2.02, 3.82, 5.1,
     7.03, 9.05, 12.12, 24.37, 0, 0.27, 0.52, 1, 1.92, 3.5, 5.02,
     7.03, 9, 12, 24.3, 0, 0.27, 0.58, 1.02, 2.02, 3.62, 5.08, 7.07,
     9, 12.15, 24.17, 0, 0.35, 0.6, 1.07, 2.13, 3.5, 5.02, 7.02, 9.02,
     11.98, 24.65, 0, 0.3, 0.52, 1, 2.02, 3.5, 5.02, 7.02, 9.1, 12,
     24.35, 0, 0.27, 0.58, 1.15, 2.03, 3.57, 5, 7, 9.22, 12.1, 23.85,
     0, 0.25, 0.5, 1.02, 2.02, 3.48, 5, 6.98, 9, 12.05, 24.22, 0,
     0.25, 0.52, 0.98, 2.02, 3.53, 5.05, 7.15, 9.07, 12.1, 24.12,
     0, 0.3, 0.63, 1.05, 2.02, 3.53, 5.02, 7.17, 8.8, 11.6, 24.43,
     0, 0.37, 0.77, 1.02, 2.05, 3.55, 5.05, 7.08, 9.38, 12.1, 23.7,
     0, 0.25, 0.5, 0.98, 1.98, 3.6, 5.02, 7.03, 9.03, 12.12, 24.08,
     0, 0.25, 0.5, 1, 2, 3.52, 5.07, 7.07, 9.03, 12.05, 24.15),
   conc = c(0.74,
     2.84, 6.57, 10.5, 9.66, 8.58, 8.36, 7.47, 6.89, 5.94, 3.28, 0,
     1.72, 7.91, 8.31, 8.33, 6.85, 6.08, 5.4, 4.55, 3.01, 0.9, 0,
     4.4, 6.9, 8.2, 7.8, 7.5, 6.2, 5.3, 4.9, 3.7, 1.05, 0, 1.89, 4.6,
     8.6, 8.38, 7.54, 6.88, 5.78, 5.33, 4.19, 1.15, 0, 2.02, 5.63,
     11.4, 9.33, 8.74, 7.56, 7.09, 5.9, 4.37, 1.57, 0, 1.29, 3.08,
     6.44, 6.32, 5.53, 4.94, 4.02, 3.46, 2.78, 0.92, 0.15, 0.85, 2.35,
     5.02, 6.58, 7.09, 6.66, 5.25, 4.39, 3.53, 1.15, 0, 3.05, 3.05,
     7.31, 7.56, 6.59, 5.88, 4.73, 4.57, 3, 1.25, 0, 7.37, 9.03, 7.14,
     6.33, 5.66, 5.67, 4.24, 4.11, 3.16, 1.12, 0.24, 2.89, 5.22, 6.41,
     7.83, 10.21, 9.18, 8.02, 7.14, 5.68, 2.42, 0, 4.86, 7.24, 8,
     6.81, 5.87, 5.22, 4.45, 3.62, 2.69, 0.86, 0, 1.25, 3.96, 7.82,
     9.72, 9.75, 8.57, 6.59, 6.11, 4.57, 1.17)),
row.names = 1:132,
class = c("nfnGroupedData", "nfGroupedData", "groupedData", "data.frame"),
formula = conc ~ Time | Subject,
labels = list(x = "Time since drug administration",
  y = "Theophylline concentration in serum"),
units = list(x = "(hr)", y = "(mg/l)"))
environment(attr(Theoph, "formula")) <- emptyenv()

==> r-base_4.3.3.orig.tar.gz: R-4.3.3/src/library/datasets/data/Theoph.R <==
### $Id: Theoph.R,v 1.1 2003/12/11 07:16:04 ripley Exp $
### Theophylline pharmacokinetic data
### Boeckmann, Sheiner, and Beal (1994), NONMEM Users Guide - Part V.
"Theoph" <-
  structure(list
  (Subject = ordered(c(11, 11, 11, 11,
     11, 11, 11, 11, 11, 11, 11, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
     5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
     7, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 1, 1, 1, 1, 1,
     1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3,
     3, 3, 3, 3, 3, 3, 3, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 10, 10,
     10, 10, 10, 10, 10, 10, 10, 10, 10, 4, 4, 4, 4, 4, 4, 4, 4, 4,
     4, 4, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9), levels=1:12,
     labels = c("6", "7", "8", "11", "3", "2", "4", "9", "12", "10",
       "1", "5")),
   Wt = c(79.6, 79.6, 79.6, 79.6, 79.6,
     79.6, 79.6, 79.6, 79.6, 79.6, 79.6, 72.4, 72.4, 72.4, 72.4, 72.4,
     72.4, 72.4, 72.4, 72.4, 72.4, 72.4, 70.5, 70.5, 70.5, 70.5, 70.5,
     70.5, 70.5, 70.5, 70.5, 70.5, 70.5, 72.7, 72.7, 72.7, 72.7, 72.7,
     72.7, 72.7, 72.7, 72.7, 72.7, 72.7, 54.6, 54.6, 54.6, 54.6, 54.6,
     54.6, 54.6, 54.6, 54.6, 54.6, 54.6, 80, 80, 80, 80, 80, 80, 80,
     80, 80, 80, 80, 64.6, 64.6, 64.6, 64.6, 64.6, 64.6, 64.6, 64.6,
     64.6, 64.6, 64.6, 70.5, 70.5, 70.5, 70.5, 70.5, 70.5, 70.5, 70.5,
     70.5, 70.5, 70.5, 86.4, 86.4, 86.4, 86.4, 86.4, 86.4, 86.4, 86.4,
     86.4, 86.4, 86.4, 58.2, 58.2, 58.2, 58.2, 58.2, 58.2, 58.2, 58.2,
     58.2, 58.2, 58.2, 65, 65, 65, 65, 65, 65, 65, 65, 65, 65, 65,
     60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5, 60.5),
   Dose = c(4.02, 4.02, 4.02, 4.02, 4.02, 4.02, 4.02, 4.02, 4.02,
     4.02, 4.02, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4,
     4.4, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 4.53,
     4.53, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4, 4.4,
     5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86, 5.86,
     4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4.95, 4.95, 4.95, 4.95, 4.95,
     4.95, 4.95, 4.95, 4.95, 4.95, 4.95, 4.53, 4.53, 4.53, 4.53, 4.53,
     4.53, 4.53, 4.53, 4.53, 4.53, 4.53, 3.1, 3.1, 3.1, 3.1, 3.1,
     3.1, 3.1, 3.1, 3.1, 3.1, 3.1, 5.5, 5.5, 5.5, 5.5, 5.5, 5.5, 5.5,
     5.5, 5.5, 5.5, 5.5, 4.92, 4.92, 4.92, 4.92, 4.92, 4.92, 4.92,
     4.92, 4.92, 4.92, 4.92, 5.3, 5.3, 5.3, 5.3, 5.3, 5.3, 5.3, 5.3,
     5.3, 5.3, 5.3),
   Time = c(0, 0.25, 0.57, 1.12, 2.02, 3.82, 5.1,
     7.03, 9.05, 12.12, 24.37, 0, 0.27, 0.52, 1, 1.92, 3.5, 5.02,
     7.03, 9, 12, 24.3, 0, 0.27, 0.58, 1.02, 2.02, 3.62, 5.08, 7.07,
     9, 12.15, 24.17, 0, 0.35, 0.6, 1.07, 2.13, 3.5, 5.02, 7.02, 9.02,
     11.98, 24.65, 0, 0.3, 0.52, 1, 2.02, 3.5, 5.02, 7.02, 9.1, 12,
     24.35, 0, 0.27, 0.58, 1.15, 2.03, 3.57, 5, 7, 9.22, 12.1, 23.85,
     0, 0.25, 0.5, 1.02, 2.02, 3.48, 5, 6.98, 9, 12.05, 24.22, 0,
     0.25, 0.52, 0.98, 2.02, 3.53, 5.05, 7.15, 9.07, 12.1, 24.12,
     0, 0.3, 0.63, 1.05, 2.02, 3.53, 5.02, 7.17, 8.8, 11.6, 24.43,
     0, 0.37, 0.77, 1.02, 2.05, 3.55, 5.05, 7.08, 9.38, 12.1, 23.7,
     0, 0.25, 0.5, 0.98, 1.98, 3.6, 5.02, 7.03, 9.03, 12.12, 24.08,
     0, 0.25, 0.5, 1, 2, 3.52, 5.07, 7.07, 9.03, 12.05, 24.15),
   conc = c(0.74,
     2.84, 6.57, 10.5, 9.66, 8.58, 8.36, 7.47, 6.89, 5.94, 3.28, 0,
     1.72, 7.91, 8.31, 8.33, 6.85, 6.08, 5.4, 4.55, 3.01, 0.9, 0,
     4.4, 6.9, 8.2, 7.8, 7.5, 6.2, 5.3, 4.9, 3.7, 1.05, 0, 1.89, 4.6,
     8.6, 8.38, 7.54, 6.88, 5.78, 5.33, 4.19, 1.15, 0, 2.02, 5.63,
     11.4, 9.33, 8.74, 7.56, 7.09, 5.9, 4.37, 1.57, 0, 1.29, 3.08,
     6.44, 6.32, 5.53, 4.94, 4.02, 3.46, 2.78, 0.92, 0.15, 0.85, 2.35,
     5.02, 6.58, 7.09, 6.66, 5.25, 4.39, 3.53, 1.15, 0, 3.05, 3.05,
     7.31, 7.56, 6.59, 5.88, 4.73, 4.57, 3, 1.25, 0, 7.37, 9.03, 7.14,
     6.33, 5.66, 5.67, 4.24, 4.11, 3.16, 1.12, 0.24, 2.89, 5.22, 6.41,
     7.83, 10.21, 9.18, 8.02, 7.14, 5.68, 2.42, 0, 4.86, 7.24, 8,
     6.81, 5.87, 5.22, 4.45, 3.62, 2.69, 0.86, 0, 1.25, 3.96, 7.82,
     9.72, 9.75, 8.57, 6.59, 6.11, 4.57, 1.17)),
row.names = 1:132,
class = c("nfnGroupedData", "nfGroupedData", "groupedData", "data.frame"),
formula = conc ~ Time | Subject,
labels = list(x = "Time since drug administration",
  y = "Theophylline concentration in serum"),
units = list(x = "(hr)", y = "(mg/l)"))
environment(attr(Theoph, "formula")) <- emptyenv()
